@@ -3,7 +3,7 @@ var indexSectionsWithContent =
   0: "_abcdefghiklmnoprstuvw",
   1: "acdfgikmprsu",
   2: "i",
-  3: "_acdefghiklprstu",
+  3: "_acdefghiklprstuv",
   4: "abcdefghiklmnoprstuv",
   5: "acdfklw"
 };
