@@ -151,6 +151,92 @@ class GetKeyErrorList(list):
             pyGetKeyQueryList.append(GetKeyError._marshalFromC(cGetKeyErrorList.ppErrors[i].contents))
         return pyGetKeyErrorList
 
+class CreateKeysRequest(object):
+    """!Class used to request multiple keys with varying attributes."""
+    class KeyRequest(object):
+        """!Inner class for CreateKeyRequest to hold groups of counts and attributes"""
+        def __init__(self, ref, count, attributes, mutableattributes = None):
+            self.ref = ref
+            self.count = count
+            self.attributes = attributes
+            self.mutableattributes = mutableattributes
+    def __init__(self, metadata = None, simulate = False):
+        """!Constructor for CreateKeyRequest.
+   
+        @param
+            metadata (MetadataDict) Optional metadata to add to the call
+        @param
+            simulate (boolean) If true, allows for testing of whether a create 
+                call would succeed without creating any keys. The response will
+                contain keys that are allowed to be created with empty ID and
+                key byte values.
+        """
+        self.metadata = metadata
+        self.simulate = simulate
+        self.keys = []
+
+    def addkeyrequest(self, ref, count, attributes, mutableattributes = None):
+        """!Method for adding a request for a number of keys with given attributes to the multiple key request
+        
+        @param
+            ref (String) A string value that will be included with the created 
+                keys that can be used to match them with the provided attributes
+        @param
+            count (int) The number of keys with the given attributes to be created
+        @param
+            attributes (KeyAttributesDict) The attributes to be set for these keys
+        @param
+            mutableattributes (KeyAttributesDict) The mutable attributes to be set
+                for these keys
+        """
+        self.keys.append(self.KeyRequest(ref, count, attributes, mutableattributes))
+
+    @staticmethod
+    def _marshalToC(pyCreateKeysRequest):
+        if pyCreateKeysRequest is None:
+            return None
+        cCreateKeysRequest = _private.cLib.ionic_create_keys_request_create()
+        _private.cLib.ionic_create_keys_request_set_simulation(cCreateKeysRequest, pyCreateKeysRequest.simulate == True)
+        if not pyCreateKeysRequest.metadata is None:
+            _private.cLib.ionic_create_keys_request_set_metadata(cCreateKeysRequest, MetadataDict._marshalToC(pyCreateKeysRequest.metadata))
+        for key in pyCreateKeysRequest.keys:
+            _private.cLib.ionic_create_keys_request_add(cCreateKeysRequest, 
+                _private.CMarshalUtil.stringToC(key.ref),
+                KeyAttributesDict._marshalToC(key.attributes),
+                KeyAttributesDict._marshalToC(key.mutableattributes),
+                key.count
+            )
+        return cCreateKeysRequest
+
+    @staticmethod
+    def _marshalFromC(cCreateKeysRequest):
+        if cCreateKeysRequest is None:
+            return None
+        cMetadata = _private.OWNED_POINTER(_private.CMetadataMap)()
+        _private.cLib.ionic_create_keys_request_get_metadata(cCreateKeysRequest, _private.byref(cMetadata))
+        cSimulate = c_bool()
+        _private.cLib.ionic_create_keys_request_get_simulation(cCreateKeysRequest, _private.byref(cSimulate))
+        pyCreateKeysRequest = CreateKeysRequest(MetadataDict._marshalFromC(cMetadata.contents), cSimulate)
+
+        cCount = c_int()
+        _private.cLib.ionic_create_keys_request_get_count(cCreateKeysRequest, _private.byref(cCount))
+        for i in range(cCount.value):
+            cKCount = c_int()
+            cRef = _private.POINTER(c_char)()
+            cAttribute = _private.OWNED_POINTER(_private.CAttributesMap)()
+            cMutable = _private.OWNED_POINTER(_private.CAttributesMap)()
+            _private.cLib.ionic_create_keys_request_get(cCreateKeysRequest, i, 
+                _private.byref(cRef),
+                _private.byref(cAttribute),
+                _private.byref(cMutable),
+                _private.byref(cKCount)
+            )
+            pyCreateKeysRequest.addkeyrequest(_private.CMarshalUtil.stringFromC(cRef), cKCount.value,
+                KeyAttributesDict._marshalFromC(cAttribute),
+                KeyAttributesDict._marshalFromC(cMutable)
+            )
+        return pyCreateKeysRequest
+
 class ResourceRequest(object):
     """!Class used to request generic resource object(s)."""
     def __init__(self, refid, resourceid, args = None):
@@ -800,6 +886,40 @@ class Agent(AgentKeyServicesBase):
         # marshal C output to Python
         return KeyDataList._marshalFromC(cKeyArray.contents)
 
+    def createkeys2(self, createkeysrequest):
+        """!Creates protection keys with various attribute sets through Ionic.com.
+        
+        This method makes an HTTP call to Ionic.com to create protection
+        keys.
+        
+        NOTE: please limit to 1,000 keys per request, otherwise the server will return an error.
+        @param
+            createkeysrequest (CreateKeysRequest) A request object that has had
+                all the desired key attribute sets and other data added to it.
+        
+        @return
+            The KeyDataList of newly created protection keys from Ionic.com.
+        """
+        # inputs
+        cReq = CreateKeysRequest._marshalToC(createkeysrequest)
+                
+        # outputs
+        self._cServerResponse = _private.OWNED_POINTER(_private.CServerResponse)()
+        cKeyArray = _private.OWNED_POINTER(_private.CKeyDataArray)()
+        
+        # call into C library to perform the work
+        try:
+            _private.cLib.ionic_agent_create_keys3(
+                self._cAgent,
+                cReq,
+                _private.byref(cKeyArray),
+                _private.byref(self._cServerResponse))
+        except Exception as e:
+            _private.raiseExceptionWithServerResponse(self._cServerResponse, e)
+        
+        # marshal C output to Python
+        return RefKeyDataList._marshalFromC(cKeyArray.contents)
+
     def getkey(self, keyid, metadata = None):
         """!Gets a single protection key from Ionic.com.
 
@@ -1160,6 +1280,37 @@ class Agent(AgentKeyServicesBase):
         # marshal C output to Python
         return _private.CMarshalUtil.stringFromC(cAssertion)
 
+    def validateassertion(self, keyspace, assertionBase64, foruri = None, nonce = None):
+        """!Given a base 64 encoded Ionic assertion, validate it against the keyspace public key.
+            This method makes an HTTP call to Ionic.com to get keyspace information including the public key.
+            It checks the assertion formating, checks the valid time window, and finally checks the RSA
+            signature against the public key for the keyspace.
+
+        @param
+            keyspace (string): The keyspace id.
+        @param
+            assertionBase64 (string): The Ionic formatted base 64 encoded assertion.
+        @param
+            foruri (string): An optional recipient string. 
+            It should match the one passed when creating the assertion.
+            If this option is left off, recipient checks are skipped.
+        @param
+            nonce (string): An optional nonce string. 
+            It should match the one passed when creating the assertion.
+            If this option is left off, the validation uses a default value.
+            If this value is incorrect, validation will fail.
+                                    
+        @return
+            None, function will throw an exception if it fails to validate.
+        """
+
+        cKeyspace = _private.CMarshalUtil.stringToC(keyspace)
+        cAssertionBase64 = _private.CMarshalUtil.stringToC(assertionBase64)
+        cForUri = _private.CMarshalUtil.stringToC(foruri)
+        cNonce = _private.CMarshalUtil.stringToC(nonce)
+
+        _private.cLib.ionic_agent_validate_assertion(self._cAgent, cKeyspace, cAssertionBase64, cForUri, cNonce)
+
     def getresource(self, resourceid, args = None, metadata = None):
         """!Gets a generic resource from Ionic.com.
 
