@@ -127,7 +127,8 @@ class KeyDataList(list):
         
         pyKeyList = KeyDataList()
         for i in range(cKeyArray.nSize):
-            pyKeyList.append(KeyData._marshalFromC(cKeyArray.ppKeyArray[i].contents))
+            key = KeyData._marshalFromC(cKeyArray.ppKeyArray[i].contents)
+            pyKeyList.append(key)
         return pyKeyList
 
     @staticmethod
@@ -139,10 +140,91 @@ class KeyDataList(list):
         cKeyDataArray = _private.cLib.ionic_create_keydata_array(len(pyKeyArray))
         
         for i in range(len(pyKeyArray)):
-            _private.cLib.ionic_set_keydata_in_array(cKeyDataArray, i, KeyData._marshalToC(pyKeyArray[i]))
+            try:
+                _private.cLib.ionic_set_keydata_in_array_with_ref(cKeyDataArray, i, KeyData._marshalToC(pyKeyArray[i]), pyKeyArray[i].ref)
+            except:
+                _private.cLib.ionic_set_keydata_in_array(cKeyDataArray, i, KeyData._marshalToC(pyKeyArray[i]))
 
         return cKeyDataArray
 
+class RefKeyData(KeyData):
+    """!Defines a data protection key as returned by Ionic.com."""
+    def __init__(self, id, bytes, attributes=None, obligations=None, origin=None, mutableAttributes=None, mutableAttributesFromServer=None, attributesSigBase64FromServer=None, mutableAttributesSigBase64FromServer=None, ref=None):
+        """!Initializes the key object with provided inputs.
+
+        @param
+            id (string): The key ID (also known as the key tag).
+        @param
+            bytes (bytes): The raw key bytes.  It must be exactly 32 bytes in length.
+        @param
+            attributes (dict[string,list[string]], optional): The key attributes.
+        @param
+            obligations (KeyObligationsDict) The key obligations
+        @param
+            origin (string) The key origin, usually a URL
+        @param
+            mutableAttributes (KeyAttributesDict) The key mutable attributes
+        @param
+            mutableAttributesFromServer (KeyAttributesDict) The key mutable attributes from the server version
+        @param
+            attributesSigBase64FromServer (string) Base 64 encoded signature of the server's non-mutable attributes
+        @param
+            mutableAttributesSigBase64FromServer (string) Base 64 encoded signature of the server's mutable attributes
+        @param
+            ref (string) A reference parameter usually returned by a request for multiple keys with different attributes
+        """
+        KeyData.__init__(self, id, bytes, attributes, obligations, origin, mutableAttributes, mutableAttributesFromServer, attributesSigBase64FromServer, mutableAttributesSigBase64FromServer)
+        ##(string) The key reference
+        self.ref = ref
+
+
+class RefKeyDataList(KeyDataList):
+    """!List of keys and associated references with convenience functions for searching.
+    """
+    def __repr__(self):
+        return '<RefKeyDataList ' + repr(self.getids()) + '>'
+    
+    def findref(self, ref):
+        """!Returns the first key object with the matching reference string, or None if not found.
+            Further matching ref values can be found by removing used keys from the list or a copy of the list.
+        @param
+            ref (string): The reference string to search for
+        @return
+            The KeyData if found, or None otherwise
+        """
+        for key in self:
+            if key.ref == ref:
+                return key
+        return None
+    
+    @staticmethod
+    def _marshalFromC(cKeyArray):
+        if cKeyArray is None:
+            return None
+        
+        pyKeyList = RefKeyDataList()
+        for i in range(cKeyArray.nSize):
+            key = RefKeyData._marshalFromC(cKeyArray.ppKeyArray[i].contents)
+            if cKeyArray.ppszRefs:
+                key.ref = _private.CMarshalUtil.stringFromC(cKeyArray.ppszRefs[i])
+            pyKeyList.append(key)
+        return pyKeyList
+
+    @staticmethod
+    def _marshalToC(pyKeyArray):
+        
+        if pyKeyArray is None:
+            return None
+    
+        cKeyDataArray = _private.cLib.ionic_create_keydata_array(len(pyKeyArray))
+        
+        for i in range(len(pyKeyArray)):
+            try:
+                _private.cLib.ionic_set_keydata_in_array_with_ref(cKeyDataArray, i, RefKeyData._marshalToC(pyKeyArray[i]), pyKeyArray[i].ref)
+            except:
+                _private.cLib.ionic_set_keydata_in_array(cKeyDataArray, i, RefKeyData._marshalToC(pyKeyArray[i]))
+
+        return cKeyDataArray
 
 class UpdateKeyData(KeyData):
     """!Defines a data protection key as returned by Ionic.com."""
@@ -655,7 +737,10 @@ class DeviceProfilePersistorPasswordFile(DeviceProfilePersistorBase):
     """!Password protected device profile persistor implementation.
     
     This class provides a file-based device persistor that is password 
-    protected.
+    protected.  The minimum password length is six characters; use of a password of
+    insufficient length will cause an
+    \ref ionicsdk.errors.IonicError.AGENT_INVALIDVALUE "AGENT_INVALIDVALUE"
+    \ref ionicsdk.exceptions.IonicException "IonicException".
     """
     def __init__(self, filepath, password):
         """!Constructs a persistor with the provided values
