@@ -131,7 +131,7 @@ This may happen if a key was found to be invalid. For example, if the key is the
          
 AGENT_STALE_KEY_ATTRIBUTES      40031
 Key updated failed because key attribute data is stale.
-This happens when a key update request is performed via ISAgent::updateKeys() or ISAgent::updateKey()
+This happens when a key update request is performed via Agent.updatekeys() or Agent.updatekey()
         and the key server denies the request because it detected that the client has a stale version
         of the key. A stale key is one which has been updated by another client without the knowledge
         of the client who requested a separate update.
@@ -140,10 +140,9 @@ This may happen, for example, if two or more different clients attempt to update
         similar time. In this case, there is a race condition, and the first client request to be
         processed works successfully, but the other clients will have their requests denied.
 
-To remedy this error, the client must retrieve the key again from the key server (via ISAgent::getKey()
-        or variants), apply the desired changes to it (via implementation of ISKeyAttributesMapMerger
-        such as ISKeyAttributesMapMergerDefault), and perform another update request via 
-        ISAgent::updateKeys() or ISAgent::updateKey().
+To remedy this error, the client must retrieve the key again from the key server (via Agent.getkey()
+        or variants), apply the desired changes to it and perform another update request via 
+        Agent.updatekeys() or Agent.updatekey().
 
 AGENT_DUPLICATE_KEY             40032
 A keys update request contains two or more entries with the same key id.
@@ -562,8 +561,8 @@ code if the specified attribute key or value does not exist.
     AGENT_INVALID_KEY                = 40030
 
     ##(int) Key updated failed because key attribute data is stale.
-    ##      This happens when a key update request is performed via ISAgent::updateKeys() or
-    ##      ISAgent::updateKey() and the key server denies the request because it detected that the client
+    ##      This happens when a key update request is performed via \link ionicsdk.agent.Agent.updatekeys() Agent.updatekeys() \endlink or
+    ##      \link ionicsdk.agent.Agent.updatekey() Agent.updatekey() \endlink and the key server denies the request because it detected that the client
     ##      has a stale version of the key. A stale key is one which has been updated by another client
     ##      without the knowledge of the client who requested a separate update.
     ##
@@ -572,9 +571,8 @@ code if the specified attribute key or value does not exist.
     ##      to be processed works successfully, but the other clients will have their requests denied.
     ##
     ##      To remedy this error, the client must retrieve the key again from the key server (via
-    ##      ISAgent::getKey() or variants), apply the desired changes to it (via implementation of
-    ##      ISKeyAttributesMapMerger such as ISKeyAttributesMapMergerDefault), and perform another
-    ##      update request via ISAgent::updateKeys() or ISAgent::updateKey().
+    ##      \link ionicsdk.agent.Agent.getkey() Agent.getkey() \endlink or variants), apply the desired changes to it and perform another
+    ##      update request via \link ionicsdk.agent.Agent.updatekeys() Agent.updatekeys() \endlink or \link ionicsdk.agent.Agent.updatekey() Agent.updatekey() \endlink.
     AGENT_STALE_KEY_ATTRIBUTES      = 40031
 
     ## A keys update request contains two or more entries with the same key id.
@@ -770,7 +768,7 @@ code if the specified attribute key or value does not exist.
     ##      This normally happens because the file path provided does not exist or it is not accessible due to lack of permission.
     HTTP_OPENFILE                    = 13010
     ##(int) Error Codes: An HTTP method was found that is not recognized.
-    ##      This happens when parsing an HTTP request and discovering an unknown / unsupportedHTTP method.
+    ##      This happens when parsing an HTTP request and discovering an unknown / unsupported HTTP method.
     ##      The supported HTTP methods are GET, POST, PUT, HEAD, and DELETE.
     HTTP_METHOD_UNKNOWN              = 13011
 
