@@ -190,10 +190,11 @@ class FileCipherDecryptAttributes(object):
         """
         We just need to update the outgoing members of this instance from the 'C' object.
         """
-        self.keydataOut = KeyData._marshalFromC(cFileDecryptAttributes.contents.pKeyResponseOut.contents)
-        self.keyidOut = self.keydataOut.id
-        self.attributesOut = self.keydataOut.attributes
-        self.mutableAttributesOut = self.keydataOut.mutableAttributes
+        if cFileDecryptAttributes.contents.pKeyResponseOut:
+            self.keydataOut = KeyData._marshalFromC(cFileDecryptAttributes.contents.pKeyResponseOut.contents)
+            self.keyidOut = self.keydataOut.id
+            self.attributesOut = self.keydataOut.attributes
+            self.mutableAttributesOut = self.keydataOut.mutableAttributes
         self.familyOut = int(cFileDecryptAttributes.contents.eFamilyOut)
         self.versionOut = _private.CMarshalUtil.stringFromC(cFileDecryptAttributes.contents.pszVersionOut)
         self.accessdeniedpageOut = _private.CMarshalUtil.bytesFromC(cFileDecryptAttributes.contents.pAccessDeniedPageOut)
@@ -380,7 +381,7 @@ class FileCipherBase(object):
                 _private.byref(cCipherTextBytes),
                 cFileEncryptAttrs)
         except Exception as e:
-            _private.raiseExceptionWithServerResponse(cFileEncryptAttrs.pServerResponseOut, e)
+            _private.raiseExceptionWithServerResponse(cFileEncryptAttrs.contents.pServerResponseOut, e)
 
         # marshal C outputs to Python
         encryptattributesInOut._updateFromC(cFileEncryptAttrs)
