@@ -177,7 +177,7 @@ class KeyVault(object):
             key via SetKey(), and the provided key is not newer than the key which already exists in the vault.
             This is not an error, per se, but it is informing the caller that the requested update is not needed, 
             and as such is ignored. The determination is made by comparing key issuance UTC time
-            (KeyVaultKeyRecord::issuedServerTimeUtcSeconds).
+            (KeyVaultKeyRecord.issuedServerTimeUtcSeconds).
     - ISKEYVAULT_OPENFILE - A file failed to open. This normally happens because the file path provided does not
             exist or it is not accessible due to lack of permission.
     - ISKEYVAULT_EOF - The end of a file was found before it was expected. This normally happens if the file has
@@ -236,7 +236,7 @@ class KeyVault(object):
     ##      This happens when attempting to update a key via SetKey(), and the provided key is not newer than the key
     ##      which already exists in the vault. This is not an error, per se, but it is informing the caller that the
     ##      requested update is not needed, and as such is ignored. The determination is made by comparing key issuance
-    ##      UTC time (KeyVaultKeyRecord::issuedServerTimeUtcSeconds).
+    ##      UTC time (KeyVaultKeyRecord.issuedServerTimeUtcSeconds).
     ISKEYVAULT_KEY_UPDATE_IGNORED = 16007
     ## Key Vault Error Codes - A file failed to open.
     ##      This normally happens because the file path provided does not exist or it is not accessible due to lack
@@ -295,7 +295,7 @@ class KeyVault(object):
 
             If the key does not exist and addIfNotFound is set to false, then ISKEYVAULT_KEY_NOT_FOUND will be returned.
 
-            If the key is found, but its 'issued' time (ISKeyVaultKey::getIssuedServerTimeUtcSeconds()) is 
+            If the key is found, but its 'issued' time (KeyVaultKeyRecord.issuedServerTimeUtcSeconds) is 
             unchanged, then the key will NOT be updated and ISKEYVAULT_KEY_UPDATE_IGNORED will be returned.
 
             If some aspect of the key itself is invalid, such as the key ID being empty, the key data not being 
@@ -596,7 +596,8 @@ class KeyVaultCustom(KeyVault):
         """!Outside of the context of a SyncKeys() callback, the Python copy of the vault keys will not have valid
             state values.  Use this function to retrieve the current state.  See class KeyVaultKeyRecord for 
             valid values.
-
+        @param
+            keyid (string) The Key ID or identifying tag
         @return
             (KeyVaultKeyRecord enum) Current key state
         """
@@ -607,7 +608,10 @@ class KeyVaultCustom(KeyVault):
         """!Inside the context of a SyncKeys() callback, the code should either update the states ISKR_UPDATED and ISKR_ADDED to ISKR_STORED, or delete keys with the status of ISKR_REMOVED.  This function updates the
             state.  It is insufficient to simply change the state on the Python object as it is a local cop of the 
             actual key data stored in the native code.
-
+        @param
+            keyid (string) The Key ID or identifying tag
+        @param
+            newState (string) The new state to set on the key
         @return
             (int) ISKEYVAULT_OK on success or ISKEYVAULT_INVALIDVALUE if this instance is corrupt somehow
         """
@@ -617,7 +621,8 @@ class KeyVaultCustom(KeyVault):
     def DeleteKey(self, keyid):
         """!Inside the context of a SyncKeys() callback, the code should either update the states ISKR_UPDATED and ISKR_ADDED to ISKR_STORED, or delete keys with the status of ISKR_REMOVED.  This function permanently
             deletes a key from the native code storage.
-
+        @param
+            keyid (string) The Key ID or identifying tag
         @return
             (int) ISKEYVAULT_OK on success or ISKEYVAULT_INVALIDVALUE if this instance is corrupt somehow
         """
@@ -627,7 +632,7 @@ class KeyVaultCustom(KeyVault):
     def SyncKeys(self, keyVaultKeys):
         """!@details
             Callback enabled by EnableSyncCallbacks().  You must sub class and override this method to use this.
-            
+        @param
             keyVaultKeys - (KeyVaultKeyRecordList)  A list of KeyVaultKeyRecords with valid state.  Use the state
             to determine new or updated keys and keys marked for removal.  This function should move the key vault
             data into long term storage and then update keys to the stored state or permanently remove them if so
@@ -641,7 +646,7 @@ class KeyVaultCustom(KeyVault):
     def SaveAllKeys(self, keyVaultKeys):
         """!Callback enabled by EnableFileLoadSaveCallbacks().  You must sub class and override this method to use
             this.
-            
+        @param
             keyVaultKeys - (KeyVaultKeyRecordList)  A list of KeyVaultKeyRecords with valid state.
             
             Function should move the key data to long term storage.  The native implementation of Sync() will update
@@ -763,8 +768,9 @@ class KeyVaultAppleKeyChain(KeyVault):
         return _private.CMarshalUtil.stringFromC(cAccessGroup)
 
     def SetProtectionKey(self, keybytes):
-        """!Setter for the AES GCM key to use for protecting the kay vault data
-
+        """!Setter for the AES GCM key to use for protecting the key vault data
+        @param
+            keybytes (bytearray) The AES GCM key to use for protecting the key vault data
         @return
             None
         """
@@ -772,8 +778,9 @@ class KeyVaultAppleKeyChain(KeyVault):
         _private.cLib.ionic_keyvault_apple_keychain_set_protection_key(self._cAgentHandle, cKeybytes)
 
     def SetProtectionAuthData(self, authbytes):
-        """!Setter for the AES GCM Additional Authenticated Data (AAD) to use for protecting the kay vault data
-
+        """!Setter for the AES GCM Additional Authenticated Data (AAD) to use for protecting the key vault data
+        @param
+            authbytes (bytearray) The AES GCM AAD to use for protecting the key vault data
         @return
             None
         """
@@ -782,7 +789,8 @@ class KeyVaultAppleKeyChain(KeyVault):
 
     def SetServiceName(self, serviceName):
         """!Setter for the Apple key chain Service Name. Defaults to "com.ionicsecurity.client.sdk.keyvault.applekeychain"
-
+        @param
+            serviceName (string) The Apple key chain Service Name
         @return
             None
         """
@@ -791,7 +799,8 @@ class KeyVaultAppleKeyChain(KeyVault):
     
     def SetAccountName(self, accountName):
         """!Setter for the Apple key chain Account Name. Defaults to "Ionic Security"
-
+        @param
+            accountName (string) The Apple key chain Account Name
         @return
             None
         """
@@ -800,7 +809,8 @@ class KeyVaultAppleKeyChain(KeyVault):
 
     def SetAccessGroup(self, accessGroup):
         """!Setter for the Apple key chain access group (iOS only).  Defaults to None.
-
+        @param
+            accessGroup (string) The Apple key chain access group (iOS only)
         @return
             None
         """
@@ -884,7 +894,7 @@ class KeyVaultMac(KeyVault):
         return _private.CMarshalUtil.stringFromC(cAccountNameOut)
 
     def GetFilePath(self):
-        """!Getter for the filename and path used to stored the keys.
+        """!Getter for the filename and path used to store the Key Vault.
 
         @return
             (string) The current file path used to store the Key Vault
@@ -894,7 +904,8 @@ class KeyVaultMac(KeyVault):
 
     def SetServiceName(self, serviceName):
         """!Setter for the Apple key chain Service Name
-
+        @param
+            serviceName (string) The Apple key chain Service Name
         @return
             None
         """
@@ -903,7 +914,8 @@ class KeyVaultMac(KeyVault):
 
     def SetAccountName(self, accountName):
         """!Setter for the Apple key chain Account Name
-
+        @param
+            accountName (string) The Apple key chain Account Name
         @return
             None
         """
@@ -911,8 +923,9 @@ class KeyVaultMac(KeyVault):
         _private.cLib.ionic_keyvault_mac_set_account_name(self._cAgentHandle, cAccountName)
 
     def SetFilePath(self, filePath):
-        """!Setter for the filename and path used to stored the keys.
-
+        """!Setter for the filename and path used to store the Key Vault.
+        @param
+            filePath (string) The filename and path used to store the Key Vault.
         @return
             None
         """
@@ -964,7 +977,8 @@ class KeyVaultWindowsDpApi(KeyVault):
 
     def SetFilePath(self, filePath):
         """!Setter for the file path used for the key vault storage
-
+        @param
+            filePath (string) The filename and path used to store the Key Vault.
         @return
             None
         """
